import { Bounds } from '../geometry/bounds';
import { LngLat } from '../geometry/lng-lat';
import { Point } from '../geometry/point';
export var sphericalMercator = {
    R: 6378137,
    MAX_LATITUDE: 85.0511287798,
    /**
     * 经纬度坐标转平面坐标
     * @param lnglat 经纬度
     */
    project: function (lnglat) {
        var d = Math.PI / 180;
        var max = this.MAX_LATITUDE;
        var lat = Math.max(Math.min(max, lnglat.lat), -max);
        var sin = Math.sin(lat * d);
        return new Point(this.R * lnglat.lng * d, (this.R * Math.log((1 + sin) / (1 - sin))) / 2);
    },
    // 平面坐标转经纬度
    unproject: function (point) {
        var d = 180 / Math.PI;
        return new LngLat((point.x * d) / this.R, (2 * Math.atan(Math.exp(point.y / this.R)) - Math.PI / 2) * d);
    },
    bounds: (function () {
        var d = 6378137 * Math.PI;
        return new Bounds([-d, -d], [d, d]);
    })(),
};
//# sourceMappingURL=spherical-mercator.js.map