"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/**
 * @fileOverview the class of Polar Coordinate
 * @author sima.zhang
 */
var matrix_util_1 = require("@antv/matrix-util");
var util_1 = require("@antv/util");
var base_1 = require("./base");
var Polar = /** @class */ (function (_super) {
    tslib_1.__extends(Polar, _super);
    function Polar(cfg) {
        var _this = _super.call(this, tslib_1.__assign({ startAngle: -Math.PI / 2, endAngle: (Math.PI * 3) / 2, innerRadius: 0 }, cfg)) || this;
        _this.type = 'polar';
        _this.isPolar = true;
        _this._init();
        return _this;
    }
    Polar.prototype._init = function () {
        var radius = this.radius;
        var innerRadius = this.innerRadius;
        var center = this.center;
        var startAngle = this.startAngle;
        var endAngle = this.endAngle;
        while (endAngle < startAngle) {
            endAngle += Math.PI * 2;
        }
        this.endAngle = endAngle;
        var oneBox = this.getOneBox();
        var oneWidth = oneBox.maxX - oneBox.minX;
        var oneHeight = oneBox.maxY - oneBox.minY;
        var left = Math.abs(oneBox.minX) / oneWidth;
        var top = Math.abs(oneBox.minY) / oneHeight;
        var width = this.width;
        var height = this.height;
        var maxRadius;
        var circleCenter;
        if (height / oneHeight > width / oneWidth) {
            // width为主
            maxRadius = width / oneWidth;
            circleCenter = {
                x: center.x - (0.5 - left) * width,
                y: center.y - (0.5 - top) * maxRadius * oneHeight,
            };
        }
        else {
            // height为主
            maxRadius = height / oneHeight;
            circleCenter = {
                x: center.x - (0.5 - left) * maxRadius * oneWidth,
                y: center.y - (0.5 - top) * height,
            };
        }
        if (!radius) {
            radius = maxRadius;
        }
        else if (radius > 0 && radius <= 1) {
            radius = maxRadius * radius;
        }
        else if (radius <= 0 || radius > maxRadius) {
            radius = maxRadius;
        }
        var x = {
            start: startAngle,
            end: endAngle,
        };
        var y = {
            start: innerRadius * radius,
            end: radius,
        };
        this.x = x;
        this.y = y;
        this.radius = radius;
        this.circleCenter = circleCenter;
    };
    Polar.prototype.getCenter = function () {
        return this.circleCenter;
    };
    Polar.prototype.getOneBox = function () {
        var startAngle = this.startAngle;
        var endAngle = this.endAngle;
        if (Math.abs(endAngle - startAngle) >= Math.PI * 2) {
            return {
                minX: -1,
                maxX: 1,
                minY: -1,
                maxY: 1,
            };
        }
        var xs = [0, Math.cos(startAngle), Math.cos(endAngle)];
        var ys = [0, Math.sin(startAngle), Math.sin(endAngle)];
        for (var i = Math.min(startAngle, endAngle); i < Math.max(startAngle, endAngle); i += Math.PI / 18) {
            xs.push(Math.cos(i));
            ys.push(Math.sin(i));
        }
        return {
            minX: Math.min.apply(Math, xs),
            maxX: Math.max.apply(Math, xs),
            minY: Math.min.apply(Math, ys),
            maxY: Math.max.apply(Math, ys),
        };
    };
    Polar.prototype.getRadius = function () {
        return this.radius;
    };
    Polar.prototype.convertPoint = function (point) {
        var center = this.getCenter();
        var x = this.isTransposed ? point.y : point.x;
        var y = this.isTransposed ? point.x : point.y;
        x = this.convertDim(x, 'x');
        y = this.convertDim(y, 'y');
        return {
            x: center.x + Math.cos(x) * y,
            y: center.y + Math.sin(x) * y,
        };
    };
    Polar.prototype.invertPoint = function (point) {
        var center = this.getCenter();
        var vPoint = [point.x - center.x, point.y - center.y];
        var x = this.x;
        var m = [1, 0, 0, 0, 1, 0, 0, 0, 1];
        matrix_util_1.mat3.rotate(m, m, x.start);
        var vStart = [1, 0, 0];
        matrix_util_1.vec3.transformMat3(vStart, vStart, m);
        vStart = [vStart[0], vStart[1]];
        var angle = matrix_util_1.vec2.angleTo(vStart, vPoint, x.end < x.start);
        if (util_1.isNumberEqual(angle, Math.PI * 2)) {
            angle = 0;
        }
        var radius = matrix_util_1.vec2.length(vPoint);
        var xPercent = angle / (x.end - x.start);
        xPercent = x.end - x.start > 0 ? xPercent : -xPercent;
        var yPercent = this.invertDim(radius, 'y');
        var rst = { x: 0, y: 0 };
        rst.x = this.isTransposed ? yPercent : xPercent;
        rst.y = this.isTransposed ? xPercent : yPercent;
        return rst;
    };
    return Polar;
}(base_1.default));
exports.default = Polar;
//# sourceMappingURL=polar.js.map